@@ -5,7 +5,8 @@
 # TODO: (FEAT) support for multiple transports on same run
 # TODO: (FEAT) support for different statistical distribution
 # TODO: (FEAT) support batch mode
-# TODO: support throughput testing thru http://linux.die.net/man/1/pv
+# TODO: (FEAT) support throughput testing thru http://linux.die.net/man/1/pv
+# TODO: (FEAT) support randomizing data fields (not only the data itself)
 
 
 import pylog_config
@@ -267,8 +268,10 @@ def generator(config=None, transport=None, formatter=None, gap=None,
     try:
         formatter_config = config['formatters'][formatter]
     except KeyError:
-        raise PylogError(
-            'formatter configuration not specified for {}'.format(formatter))
+        # raise PylogError(
+        #     'formatter configuration not specified for {}'.format(formatter))
+        lgr.info('formatter configuration not specified.')
+        formatter_config = []
     # configure transport instance and client
     instance, client = config_transport(trans, transport, transport_config)
     # log messages
